@@ -1,5 +1,5 @@
 from bs4 import BeautifulSoup
-from ._helpers import text_values, lists2dict
+from ._helpers import text_values, lists2dict, MetaList
 
 
 def docket(oscn_html):
@@ -7,7 +7,9 @@ def docket(oscn_html):
     docket_table = soup.find('table', 'docketlist')
     thead = docket_table.find('thead').find_all('th')
     rows = docket_table.find('tbody').find_all('tr')
-    minutes = []
+
+    minutes = MetaList()
+    minutes.text = docket_table.text
 
     # make a lower case list of column headers
     columns = [hdr for hdr in map(lambda str:str.lower(), text_values(thead))]
